dsp: fix no recovery after SSR/PDR

Add apr_reset for q6core service to enable glink channel
to close and open properly after SSR.

CRs-Fixed: 2099312
Change-Id: Ia023cdb19a6a9dc7fae3e5c28ab51ddd92d37527
Signed-off-by: Tanya Dixit <tdixit@codeaurora.org>
diff --git a/dsp/q6core.c b/dsp/q6core.c
index 8d82704..95b203a 100644
--- a/dsp/q6core.c
+++ b/dsp/q6core.c
@@ -210,7 +210,11 @@
 	case RESET_EVENTS:{
 		pr_debug("%s: Reset event received in Core service\n",
 			__func__);
-		/* no reset done as the data will not change after SSR*/
+		/*
+		 * no reset for q6core_avcs_ver_info done as
+		 * the data will not change after SSR
+		 */
+		apr_reset(q6core_lcl.core_handle_q);
 		q6core_lcl.core_handle_q = NULL;
 		break;
 	}